@@ -12,8 +12,8 @@ if($m_nRight <= 1) {
       my $wrong_captcha_text = translate("wrong_captcha_text");
       use Authen::Captcha;
       my $captcha = Authen::Captcha->new(
-	data_folder   => "config/",
-	output_folder => "../images",
+	data_folder   => "$m_hrSettings->{cgi}{bin}/config/",
+	output_folder => "$m_hrSettings->{cgi}{DocumentRoot}/images",
 	expire        => 300);
       my $md5sum = $captcha->generate_code(3);
       $authen = qq|<input size="5" type="hidden" name="md5" value="$md5sum"/>
