@@ -1,47 +1,46 @@
 $VAR1 = {
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'scriptAlias' => 'perl',
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
-          'database' => {
-                          'CurrentHost' => 'localhost',
-                          'CurrentUser' => 'root',
-                          'CurrentDb' => 'LZE',
-                          'user' => 'root',
-                          'name' => 'LZE',
-                          'host' => 'localhost',
-                          'CurrentPass' => 'keinz',
-                          'password' => 'keinz'
-                        },
-          'version' => '0.85',
-          'mod' => 1,
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'language' => 'en',
           'cgi' => {
+                     'expires' => '+1y',
                      'style' => 'mysql',
+                     'title' => 'MySQL::Admin',
                      'bin' => '/var/www/cgi-bin',
                      'serverName' => 'localhost',
                      'cookiePath' => '/',
-                     'DocumentRoot' => '/var/www/htdocs',
                      'alias' => 'perl',
-                     'title' => 'MySQL::Admin',
-                     'expires' => '+1y'
+                     'DocumentRoot' => '/var/www/htdocs'
                    },
-          'floodtime' => 10,
-          'admin' => {
-                       'email' => 'your@email.org',
-                       'password' => 'testpass'
-                     },
-          'files' => {
-                       'chmod' => '0755',
-                       'group' => 'lze',
-                       'owner' => 'lze'
-                     },
           'uploads' => {
                          'chmod' => 438,
                          'maxlength' => 21000000,
                          'path' => '/var/www/htdocs/download'
                        },
-          'translate' => '/var/www/cgi-bin/config/translate.pl'
+          'scriptAlias' => 'perl',
+          'floodtime' => 10,
+          'mod' => 1,
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'database' => {
+                          'password' => '',
+                          'CurrentPass' => '',
+                          'host' => 'localhost',
+                          'name' => 'LZE',
+                          'CurrentHost' => 'localhost',
+                          'user' => 'root',
+                          'CurrentDb' => 'LZE',
+                          'CurrentUser' => 'root'
+                        },
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'version' => '0.86',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'admin' => {
+                       'password' => 'testpass'
+                     },
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'files' => {
+                       'owner' => 'lze',
+                       'group' => 'lze',
+                       'chmod' => '0755'
+                     },
+          'language' => 'en'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
