@@ -1,3 +1,4 @@
+use utf8;
 use lib qw(/var/www/cgi-bin/lib);
 ##################################################################################
 #      path is set during make                                                    #
@@ -14,19 +15,18 @@ use URI::Escape;
 # enable if the mod_perl 1.0 compatibility is needed
 # use Apache2::compat ();
 # preload all mp2 modules
-use ModPerl::MethodLookup;
-ModPerl::MethodLookup::preload_all_modules();
-use ModPerl::Util        ();    #for CORE::GLOBAL::exit
-use Apache2::RequestRec  ();
-use Apache2::RequestIO   ();
-use Apache2::RequestUtil ();
-use Apache2::ServerRec   ();
-use Apache2::ServerUtil  ();
-use Apache2::Connection  ();
-use Apache2::Log         ();
-use APR::Table           ();
-use ModPerl::Registry    ();
-use Apache2::Const -compile => ':common';
-use APR::Const -compile     => ':common';
-
+# use ModPerl::MethodLookup;
+# ModPerl::MethodLookup::preload_all_modules();
+# use ModPerl::Util        ();    #for CORE::GLOBAL::exit
+# use Apache2::RequestRec  ();
+# use Apache2::RequestIO   ();
+# use Apache2::RequestUtil ();
+# use Apache2::ServerUtil  ();
+# use Apache2::Connection  ();
+# use Apache2::Log         ();
+# use APR::Table           ();
+# use ModPerl::Registry    ();
+# use APR::Const    -compile => qw(:error SUCCESS);
+# use Apache2::Const -compile => qw(:log);
+# use Apache2::ServerRec qw(warn);
 1;
