@@ -1,6 +1,7 @@
 package DBI::Library;
 use strict;
-use warnings;
+use warnings FATAL => 'all';
+no warnings 'redefine';
 use utf8;
 use vars qw( 
 $m_dbh 
@@ -33,7 +34,7 @@ $m_sDefaultClass = 'DBI::Library' unless defined $DBI::Library::m_sDefaultClass;
         qw(quote quote_identifier CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute selectTable)
     ],
 );
-$DBI::Library::VERSION = '0.85';
+$DBI::Library::VERSION = '0.86';
 $m_tbl                 = 'querys';
 $driver                = 'mysql';
 require Exporter;
