@@ -2,7 +2,8 @@ package HTML::Menu::Pages;
 use Template::Quick;
 use strict;
 use utf8;
-use warnings;
+use warnings FATAL => 'all';
+no warnings 'redefine';
 require Exporter;
 use vars qw(
   $DefaultClass
@@ -21,7 +22,7 @@ use vars qw(
 );
 @HTML::Menu::Pages::EXPORT  = qw(makePages);
 @ISA                        = qw(Exporter);
-$HTML::Menu::Pages::VERSION = '0.84';
+$HTML::Menu::Pages::VERSION = '0.86';
 $DefaultClass               = 'HTML::Menu::Pages' unless defined $HTML::Menu::Pages::DefaultClass;
 
 =head1 NAME
