@@ -1,14 +1,15 @@
 package Template::Quick;
 use strict;
 use utf8;
-use warnings;
+use warnings FATAL => 'all';
+no warnings 'redefine';
 use MySQL::Admin qw(init translate);
 require Exporter;
 use vars qw($defaultconfig $tmp $DefaultClass @EXPORT_OK @ISA $sStyle $bModPerl);
 @ISA                          = qw(Exporter);
 @Template::Quick::EXPORT      = qw(initTemplate appendHash Template initArray);
 %Template::Quick::EXPORT_TAGS = ('all' => [qw(initTemplate appendHash Template initArray  )]);
-$Template::Quick::VERSION     = '0.85';
+$Template::Quick::VERSION     = '0.86';
 $DefaultClass                 = 'Template::Quick' unless defined $Template::Quick::DefaultClass;
 our %tmplate;
 $sStyle      = 'mysql';
